@@ -128,6 +128,7 @@ class iPhotoDB:
 
         # initialize database dictionaries
         self._db_photos = {}  # mapping of uuid to photo data
+        self._dbphotos = self._db_photos  # for compatability with PhotosDB
         self._db_event_notes = {}  # mapping of modelId to event notes
         self._db_places = {}  # mapping of modelId to places
         self._db_properties = {}  # mapping of versionId to properties
@@ -139,9 +140,10 @@ class iPhotoDB:
         self._db_albums = {}  # mapping of modelId to albums
         self._db_volumes = {}  # mapping of volume uuid to volume name
 
-        # set _db_version and _photos_ver even though they're not used in iPhoto because other code depends on these
+        # set _db_version, _photos_ver, _model_ver even though they're not used in iPhoto because other code depends on these
         self._db_version = _IPHOTO_VERSION
         self._photos_ver = 0
+        self._model_ver = 0
 
         self._load_library()
 
@@ -1070,6 +1072,11 @@ class iPhotoPhotoInfo:
             default=True,
         )
 
+    @property
+    def date_original(self) -> datetime.datetime:
+        """Date photo was taken"""
+        return self.date
+
     @property
     def date_modified(self) -> datetime.datetime:
         """Date modified in library"""
@@ -1097,6 +1104,11 @@ class iPhotoPhotoInfo:
         tz = ZoneInfo(tzname)
         return int(tz.utcoffset(self.date).total_seconds())
 
+    @property
+    def tzname(self) -> str | None:
+        """Timezone name for the asset creation date"""
+        return self._db._db_photos[self._uuid]["timezone"] or None
+
     @property
     def path(self) -> str | None:
         """Path to original photo asset in library"""
@@ -1676,6 +1688,9 @@ class iPhotoPhotoInfo:
             dict_data["shared_moment"] = self.shared_moment
             dict_data["shared_library"] = self.shared_library
             dict_data["rating"] = self.rating
+            dict_data["screen_recording"] = self.screen_recording
+            dict_data["date_original"] = self.date_original
+            dict_data["tzname"] = self.tzname
 
         return dict_data
 
