@@ -1,4 +1,4 @@
-""" Update the timezone of a photo in Apple Photos' library """
+"""Update the timezone of a photo in Apple Photos' library"""
 
 # WARNING: This is a hack.  It might destroy your Photos library.
 # Ensure you have a backup before using!
@@ -151,7 +151,8 @@ class PhotoTimeZoneUpdater:
                 c.execute(sql)
                 results = c.fetchone()
 
-            if results[2] == self.tz_offset and results[3] == self.tz_name:
+            photo_tz_offset = self.timezone.offset_for_date(photo.date)
+            if results[2] == photo_tz_offset and results[3] == self.tz_name:
                 self.verbose(
                     f"Skipping timezone update for photo [filename]{photo.filename}[/filename] ([uuid]{photo.uuid}[/uuid]): nothing to do"
                 )
@@ -163,7 +164,7 @@ class PhotoTimeZoneUpdater:
             tz_name = results[3]
             sql_update = f"""   UPDATE ZADDITIONALASSETATTRIBUTES
                                 SET Z_OPT={z_opt},
-                                ZTIMEZONEOFFSET={self.tz_offset},
+                                ZTIMEZONEOFFSET={photo_tz_offset},
                                 ZTIMEZONENAME='{self.tz_name}'
                                 WHERE Z_PK={z_pk};
                         """
@@ -180,9 +181,10 @@ class PhotoTimeZoneUpdater:
             photo.date = photo.date - datetime.timedelta(seconds=1)
 
             self.verbose(
-                f"Updated timezone for photo [filename]{photo.filename}[/filename] ([uuid]{photo.uuid}[/uuid]) "
-                + f"from [tz]{tz_name}[/tz], offset=[tz]{tz_offset}[/tz] "
-                + f"to [tz]{self.tz_name}[/tz], offset=[tz]{self.tz_offset}[/tz]"
+                "Updated timezone for photo "
+                f"[filename]{photo.filename}[/filename] ([uuid]{photo.uuid}[/uuid]) "
+                f"from [tz]{tz_name}[/tz], offset=[tz]{tz_offset}[/tz] "
+                f"to [tz]{self.tz_name}[/tz], offset=[tz]{photo_tz_offset}[/tz]"
             )
         except Exception as e:
             raise e
