@@ -1,4 +1,4 @@
-""" Tests which require user interaction to run for osxphotos timewarp command """
+"""Tests which require user interaction to run for osxphotos timewarp command"""
 
 import datetime
 import os
@@ -8,6 +8,7 @@ import pytest
 from click.testing import CliRunner
 
 from osxphotos import PhotosDB
+from osxphotos.cli.timewarp import timewarp
 from osxphotos.exiftool import ExifTool
 from tests.conftest import get_os_version
 from tests.parse_timewarp_output import (
@@ -90,7 +91,6 @@ def ask_user_to_make_selection(
 @pytest.mark.timewarp
 def test_inspect(photoslib, suspend_capture):
     """Test --inspect. NOTE: this test requires user interaction"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -106,7 +106,6 @@ def test_inspect(photoslib, suspend_capture):
 @pytest.mark.timewarp
 def test_date(photoslib, suspend_capture):
     """Test --date"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -130,7 +129,6 @@ def test_date(photoslib, suspend_capture):
 @pytest.mark.parametrize("input_value,expected", TEST_DATA["date_delta"]["parameters"])
 def test_date_delta(photoslib, suspend_capture, input_value, expected):
     """Test --date-delta"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -146,6 +144,8 @@ def test_date_delta(photoslib, suspend_capture, input_value, expected):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
+
     result = runner.invoke(
         timewarp,
         ["--inspect", "--plain", "--force", "--uuid", UUID_DICT["pears"]],
@@ -159,7 +159,6 @@ def test_date_delta(photoslib, suspend_capture, input_value, expected):
 @pytest.mark.parametrize("input_value,expected", TEST_DATA["time"]["parameters"])
 def test_time(photoslib, suspend_capture, input_value, expected):
     """Test --time"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -168,6 +167,8 @@ def test_time(photoslib, suspend_capture, input_value, expected):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
+
     # inspect to get the updated times
     # don't use photo.date as it will return local time instead of the time in the timezone
     result = runner.invoke(
@@ -184,7 +185,6 @@ def test_time(photoslib, suspend_capture, input_value, expected):
 @pytest.mark.parametrize("input_value,expected", TEST_DATA["time_delta"]["parameters"])
 def test_time_delta(photoslib, suspend_capture, input_value, expected):
     """Test --time-delta"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -200,6 +200,8 @@ def test_time_delta(photoslib, suspend_capture, input_value, expected):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
+
     result = runner.invoke(
         timewarp,
         ["--inspect", "--plain", "--force", "--uuid", UUID_DICT["pears"]],
@@ -217,7 +219,6 @@ def test_time_zone(
     photoslib, suspend_capture, input_value, expected_date, expected_tz, output_file
 ):
     """Test --time-zone"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -226,6 +227,8 @@ def test_time_zone(
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
+
     result = runner.invoke(
         timewarp,
         ["--inspect", "--plain", "--force", "--uuid", UUID_DICT["pears"]],
@@ -240,7 +243,6 @@ def test_time_zone(
 @pytest.mark.parametrize("expected", TEST_DATA["compare_exif"]["expected"])
 def test_compare_exif(photoslib, suspend_capture, expected):
     """Test --compare-exif"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -259,7 +261,6 @@ def test_compare_exif(photoslib, suspend_capture, expected):
 )
 def test_compare_exif_add_to_album(photoslib, suspend_capture, expected, album):
     """Test --compare-exif --add-to-album"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -291,7 +292,6 @@ def test_compare_exif_add_to_album(photoslib, suspend_capture, expected, album):
 @pytest.mark.parametrize("expected", TEST_DATA["compare_exif_3"]["expected"])
 def test_compare_exif_3(photoslib, suspend_capture, expected):
     """Test --compare-exif"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -308,7 +308,6 @@ def test_compare_exif_3(photoslib, suspend_capture, expected):
 @pytest.mark.parametrize("input_value,expected", TEST_DATA["match"]["parameters"])
 def test_match(photoslib, suspend_capture, input_value, expected):
     """Test --timezone --match"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -325,6 +324,8 @@ def test_match(photoslib, suspend_capture, input_value, expected):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
+
     result = runner.invoke(
         timewarp,
         ["--inspect", "--plain", "--force", "--uuid", UUID_DICT["sunflowers"]],
@@ -334,10 +335,126 @@ def test_match(photoslib, suspend_capture, input_value, expected):
     assert output_values[0].date_tz == expected
 
 
+@pytest.mark.timewarp
+def test_match_dst(photoslib, suspend_capture):
+    """Test --timezone --match-time for DST and named timezones, #1777"""
+
+    runner = CliRunner()
+    # init the date/time
+    result = runner.invoke(
+        timewarp,
+        [
+            "--time",
+            "21:26:51",
+            "--date",
+            "2017-06-24",
+            "--plain",
+            "--force",
+            "--timezone",
+            "-0500",
+            "--match-time",
+            "--uuid",
+            UUID_DICT["sunflowers"],
+        ],
+        terminal_width=TERMINAL_WIDTH,
+    )
+    assert result.exit_code == 0
+    time.sleep(1)
+
+    result = runner.invoke(
+        timewarp,
+        ["--inspect", "--plain", "--force", "--uuid", UUID_DICT["sunflowers"]],
+        terminal_width=TERMINAL_WIDTH,
+    )
+    output_values = parse_inspect_output(result.output)
+    assert output_values[0].date_tz != "2017-06-24 21:26:51+0200"
+
+    result = runner.invoke(
+        timewarp,
+        [
+            "--timezone",
+            "Europe/Madrid",
+            "--match-time",
+            "--plain",
+            "--force",
+            "--uuid",
+            UUID_DICT["sunflowers"],
+        ],
+        terminal_width=TERMINAL_WIDTH,
+    )
+    assert result.exit_code == 0
+
+    result = runner.invoke(
+        timewarp,
+        ["--inspect", "--plain", "--force", "--uuid", UUID_DICT["sunflowers"]],
+        terminal_width=TERMINAL_WIDTH,
+    )
+    output_values = parse_inspect_output(result.output)
+    assert output_values[0].date_tz == "2017-06-24 21:26:51+0200"
+
+
+@pytest.mark.timewarp
+def test_match_no_dst(photoslib, suspend_capture):
+    """Test --timezone --match-time when not in DST and named timezones, #1777"""
+
+    runner = CliRunner()
+    # init the date/time
+    result = runner.invoke(
+        timewarp,
+        [
+            "--time",
+            "21:26:51",
+            "--date",
+            "2017-12-24",
+            "--plain",
+            "--force",
+            "--timezone",
+            "-0500",
+            "--match-time",
+            "--uuid",
+            UUID_DICT["sunflowers"],
+        ],
+        terminal_width=TERMINAL_WIDTH,
+    )
+    assert result.exit_code == 0
+    time.sleep(1)
+
+    result = runner.invoke(
+        timewarp,
+        ["--inspect", "--plain", "--force", "--uuid", UUID_DICT["sunflowers"]],
+        terminal_width=TERMINAL_WIDTH,
+    )
+    output_values = parse_inspect_output(result.output)
+    assert output_values[0].date_tz != "2017-12-24 21:26:51+0100"
+
+    result = runner.invoke(
+        timewarp,
+        [
+            "--timezone",
+            "Europe/Madrid",
+            "--match-time",
+            "--plain",
+            "--force",
+            "--uuid",
+            UUID_DICT["sunflowers"],
+        ],
+        terminal_width=TERMINAL_WIDTH,
+    )
+    assert result.exit_code == 0
+    time.sleep(1)
+
+    result = runner.invoke(
+        timewarp,
+        ["--inspect", "--plain", "--force", "--uuid", UUID_DICT["sunflowers"]],
+        terminal_width=TERMINAL_WIDTH,
+    )
+    output_values = parse_inspect_output(result.output)
+    assert output_values[0].date_tz == "2017-12-24 21:26:51+0100"
+
+
 @pytest.mark.timewarp
 def test_push_exif_missing_file():
     """Test --push-exif when an original file is missing"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -378,7 +495,6 @@ def test_push_exif_1(
     output_file,
 ):
     """Test --timezone --match with --push-exif"""
-    from osxphotos.cli.timewarp import timewarp
 
     cli_args = [
         "--timezone",
@@ -397,6 +513,8 @@ def test_push_exif_1(
     runner = CliRunner()
     result = runner.invoke(timewarp, cli_args, terminal_width=TERMINAL_WIDTH)
     assert result.exit_code == 0
+    time.sleep(1)
+
     result = runner.invoke(
         timewarp,
         ["--inspect", "--plain", "--force", "--uuid", UUID_DICT["pumpkins"]],
@@ -426,8 +544,6 @@ def test_push_exif_2(photoslib, suspend_capture):
     pre_test = TEST_DATA["push_exif"]["pre"]
     post_test = TEST_DATA["push_exif"]["post"]
 
-    from osxphotos.cli.timewarp import timewarp
-
     runner = CliRunner()
 
     result = runner.invoke(
@@ -437,6 +553,7 @@ def test_push_exif_2(photoslib, suspend_capture):
     )
     output_values = parse_compare_exif(result.output)
     assert output_values[0] == pre_test
+    time.sleep(1)
 
     result = runner.invoke(
         timewarp,
@@ -467,8 +584,6 @@ def test_pull_exif_1(photoslib, suspend_capture):
     pre_test = TEST_DATA["pull_exif_1"]["pre"]
     post_test = TEST_DATA["pull_exif_1"]["post"]
 
-    from osxphotos.cli.timewarp import timewarp
-
     runner = CliRunner()
 
     # update the photo so we know if the data is updated
@@ -489,6 +604,7 @@ def test_pull_exif_1(photoslib, suspend_capture):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
 
     result = runner.invoke(
         timewarp,
@@ -533,8 +649,6 @@ def test_pull_exif_no_time(photoslib, suspend_capture):
     pre_test = TEST_DATA["pull_exif_no_time"]["pre"]
     post_test = TEST_DATA["pull_exif_no_time"]["post"]
 
-    from osxphotos.cli.timewarp import timewarp
-
     runner = CliRunner()
 
     result = runner.invoke(
@@ -558,6 +672,7 @@ def test_pull_exif_no_time(photoslib, suspend_capture):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
 
     result = runner.invoke(
         timewarp,
@@ -580,8 +695,6 @@ def test_pull_exif_no_offset(photoslib, suspend_capture):
     pre_test = TEST_DATA["pull_exif_no_offset"]["pre"]
     post_test = TEST_DATA["pull_exif_no_offset"]["post"]
 
-    from osxphotos.cli.timewarp import timewarp
-
     runner = CliRunner()
 
     result = runner.invoke(
@@ -605,6 +718,7 @@ def test_pull_exif_no_offset(photoslib, suspend_capture):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
 
     result = runner.invoke(
         timewarp,
@@ -629,8 +743,6 @@ def test_pull_exif_no_data(photoslib, suspend_capture):
     pre_test = TEST_DATA["pull_exif_no_data"]["pre"]
     post_test = TEST_DATA["pull_exif_no_data"]["post"]
 
-    from osxphotos.cli.timewarp import timewarp
-
     runner = CliRunner()
 
     result = runner.invoke(
@@ -671,8 +783,6 @@ def test_pull_exif_no_data_use_file_time(photoslib, suspend_capture):
     pre_test = TEST_DATA["pull_exif_no_data_use_file_time"]["pre"]
     post_test = TEST_DATA["pull_exif_no_data_use_file_time"]["post"]
 
-    from osxphotos.cli.timewarp import timewarp
-
     runner = CliRunner()
 
     result = runner.invoke(
@@ -718,7 +828,6 @@ def test_pull_exif_no_data_use_file_time(photoslib, suspend_capture):
 @pytest.mark.parametrize("expected", TEST_DATA["compare_video_1"]["expected"])
 def test_video_compare_exif(photoslib, suspend_capture, expected):
     """Test --compare-exif with video"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -739,7 +848,6 @@ def test_video_date_delta(
     photoslib, suspend_capture, input_value, expected, output_file
 ):
     """Test --date-delta with video"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -755,6 +863,7 @@ def test_video_date_delta(
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
 
     result = runner.invoke(
         timewarp,
@@ -773,7 +882,6 @@ def test_video_time_delta(
     photoslib, suspend_capture, input_value, expected, output_file
 ):
     """Test --time-delta with video"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -789,6 +897,8 @@ def test_video_time_delta(
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
+
     result = runner.invoke(
         timewarp,
         ["--inspect", "--plain", "--force", "--uuid", UUID_DICT["sunset_video"]],
@@ -802,7 +912,6 @@ def test_video_time_delta(
 @pytest.mark.parametrize("input_value,expected", TEST_DATA["video_date"]["parameters"])
 def test_video_date(photoslib, suspend_capture, input_value, expected):
     """Test --date with video"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -818,6 +927,8 @@ def test_video_date(photoslib, suspend_capture, input_value, expected):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
+
     # inspect to get the updated times
     # don't use photo.date as it will return local time instead of the time in the timezone
     result = runner.invoke(
@@ -833,7 +944,6 @@ def test_video_date(photoslib, suspend_capture, input_value, expected):
 @pytest.mark.parametrize("input_value,expected", TEST_DATA["video_time"]["parameters"])
 def test_video_time(photoslib, suspend_capture, input_value, expected):
     """Test --time with video"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -849,6 +959,8 @@ def test_video_time(photoslib, suspend_capture, input_value, expected):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
+
     # inspect to get the updated times
     # don't use photo.date as it will return local time instead of the time in the timezone
     result = runner.invoke(
@@ -868,7 +980,6 @@ def test_video_time_zone(
     photoslib, suspend_capture, input_value, expected_date, expected_tz, output_file
 ):
     """Test --time-zone"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -884,6 +995,8 @@ def test_video_time_zone(
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
+
     result = runner.invoke(
         timewarp,
         ["--inspect", "--plain", "--force", "--uuid", UUID_DICT["sunset_video"]],
@@ -898,7 +1011,6 @@ def test_video_time_zone(
 @pytest.mark.parametrize("input_value,expected", TEST_DATA["video_match"]["parameters"])
 def test_video_match(photoslib, suspend_capture, input_value, expected):
     """Test --timezone --match with video"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -915,6 +1027,8 @@ def test_video_match(photoslib, suspend_capture, input_value, expected):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
+
     result = runner.invoke(
         timewarp,
         ["--inspect", "--plain", "--force", "--uuid", UUID_DICT["sunset_video"]],
@@ -930,8 +1044,6 @@ def test_video_push_exif(photoslib, suspend_capture):
     pre_test = TEST_DATA["video_push_exif"]["pre"]
     post_test = TEST_DATA["video_push_exif"]["post"]
 
-    from osxphotos.cli.timewarp import timewarp
-
     runner = CliRunner()
 
     result = runner.invoke(
@@ -955,6 +1067,7 @@ def test_video_push_exif(photoslib, suspend_capture):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
 
     result = runner.invoke(
         timewarp,
@@ -971,8 +1084,6 @@ def test_video_pull_exif(photoslib, suspend_capture):
     pre_test = TEST_DATA["video_pull_exif"]["pre"]
     post_test = TEST_DATA["video_pull_exif"]["post"]
 
-    from osxphotos.cli.timewarp import timewarp
-
     runner = CliRunner()
 
     # update the photo so we know if the data is updated
@@ -1017,6 +1128,7 @@ def test_video_pull_exif(photoslib, suspend_capture):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
 
     result = runner.invoke(
         timewarp,
@@ -1036,7 +1148,6 @@ def test_video_pull_exif(photoslib, suspend_capture):
 @pytest.mark.timewarp
 def test_function(photoslib, suspend_capture):
     """Test timewarp function"""
-    from osxphotos.cli.timewarp import timewarp
 
     expected = TEST_DATA["function"]["expected"]
 
@@ -1053,6 +1164,8 @@ def test_function(photoslib, suspend_capture):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
+
     result = runner.invoke(
         timewarp,
         ["--inspect", "--plain", "--force", "--uuid", UUID_DICT["pears"]],
@@ -1071,7 +1184,6 @@ def test_function(photoslib, suspend_capture):
 @pytest.mark.timewarp
 def test_parse_date(photoslib, suspend_capture):
     """Test --parse-date"""
-    from osxphotos.cli.timewarp import timewarp
 
     expected = TEST_DATA["parse_date"]["expected"]
 
@@ -1082,6 +1194,8 @@ def test_parse_date(photoslib, suspend_capture):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
+
     result = runner.invoke(
         timewarp,
         ["--inspect", "--plain", "--force", "--uuid", UUID_DICT["palm_tree"]],
@@ -1094,7 +1208,6 @@ def test_parse_date(photoslib, suspend_capture):
 @pytest.mark.timewarp
 def test_parse_date_tz(photoslib, suspend_capture):
     """Test --parse-date with a timezone"""
-    from osxphotos.cli.timewarp import timewarp
 
     expected = TEST_DATA["parse_date_tz"]["expected"]
 
@@ -1111,6 +1224,8 @@ def test_parse_date_tz(photoslib, suspend_capture):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
+
     result = runner.invoke(
         timewarp,
         ["--inspect", "--plain", "--force", "--uuid", UUID_DICT["palm_tree"]],
@@ -1129,7 +1244,6 @@ def test_date_added(
     photoslib, suspend_capture, date_added: str, expected: InspectValuesDateAdded
 ):
     """Test --date-added"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -1138,6 +1252,7 @@ def test_date_added(
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
 
     result = runner.invoke(
         timewarp,
@@ -1151,7 +1266,6 @@ def test_date_added(
 @pytest.mark.timewarp
 def test_date_added_from_photo(photoslib, suspend_capture):
     """Test --date-added-from-photo"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -1160,6 +1274,7 @@ def test_date_added_from_photo(photoslib, suspend_capture):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
 
     result = runner.invoke(
         timewarp,
@@ -1174,7 +1289,6 @@ def test_date_added_from_photo(photoslib, suspend_capture):
 @pytest.mark.timewarp
 def test_reset(photoslib, suspend_capture):
     """Test --reset"""
-    from osxphotos.cli.timewarp import timewarp
 
     runner = CliRunner()
     result = runner.invoke(
@@ -1183,6 +1297,7 @@ def test_reset(photoslib, suspend_capture):
         terminal_width=TERMINAL_WIDTH,
     )
     assert result.exit_code == 0
+    time.sleep(1)
 
     result = runner.invoke(
         timewarp,
